@@ -30,7 +30,7 @@ sub _build_json_coder {
 our %_TypeToCode= (
 	file => ord('f'), dir => ord('d'), symlink => ord('l'),
 	chardev => ord('c'), blockdev => ord('b'),
-	pipe => ord('p'), socket => ord('s')
+	pipe => ord('p'), socket => ord('s'), whiteout => ord('w'),
 );
 our %_CodeToType= map { $_TypeToCode{$_} => $_ } keys %_TypeToCode;
 our @_FieldOrder= qw(
@@ -213,7 +213,7 @@ DataStore::CAS::FS::DirCodec::Unix - Efficiently encode only the attributes of a
 
 =head1 VERSION
 
-version 0.010100_03
+version 0.010100_04
 
 =head1 DESCRIPTION
 
